Djem
====

|build| |coverage| |docs| |pypi| |pyversions| |djversions| |license|


A collection of useful stuff for Django projects.


Requirements
------------

* Django 1.11+
* `pytz <http://pytz.sourceforge.net/>`_ is required to make use of ``TimeZoneField``


Installation
------------

Install the latest stable version from PyPI:

.. code-block:: bash

    pip install djem


Documentation
-------------

Full documentation can be found at: https://djem.readthedocs.io.


.. |build| image:: https://travis-ci.org/oogles/djem.svg?branch=master
    :alt: Build status
    :target: https://travis-ci.org/oogles/djem

.. |coverage| image:: https://coveralls.io/repos/github/oogles/djem/badge.svg?branch=master
    :alt: Test suite coverage
    :target: https://coveralls.io/github/oogles/djem?branch=master

.. |docs| image:: https://readthedocs.org/projects/djem/badge/?version=latest
    :alt: Latest documentation build
    :target: http://djem.readthedocs.io/en/latest/?badge=latest

.. |pypi| image:: https://img.shields.io/pypi/v/djem.svg
    :alt: Latest release version
    :target: https://pypi.python.org/pypi/djem/

.. |pyversions| image:: https://img.shields.io/pypi/pyversions/djem.svg
    :alt: Supported Python versions

.. |djversions| image:: https://img.shields.io/pypi/djversions/djem.svg
    :alt: Supported Django versions

.. |license| image:: https://img.shields.io/pypi/l/djem.svg
    :alt: License
